/* pathdef.c */
/* This file is automatically created by Makefile
 * DO NOT EDIT!  Change Makefile only. */
#include "vim.h"
char_u *default_vim_dir = (char_u *)"/usr/share/vim";
char_u *default_vimruntime_dir = (char_u *)"";
char_u *all_cflags = (char_u *)"";
char_u *all_lflags = (char_u *)"";
char_u *compiled_user = (char_u *)"";
char_u *compiled_sys = (char_u *)"";
